priority property

int? priority
getter/setter pair

Priority of the alarm: 0 = low, 1 = medium, 2 = high, 3 = critical

Minimum value: 0 Maximum value: 3

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

int? priority;