AssetsMetricS7 class

Implemented types

Constructors

AssetsMetricS7({required String name, required int interval, required RetPolicy retPolicy, required AssetsMetricS7DataTypeEnum dataType, required AssetsMetricS7MemoryAreaEnum memoryArea, required num memoryAddress, required MetricPermission permissions, required AccessLevel accessLevel, required List<MetricCategory> category, String? topic = 'mdm', String? description, num? dataBlockAddress, num? stringLength, num? bitOffset, num? min, num? max, Unit? unit, Tags? tags, AssetsMetricS7ActivationEdgeEnum? activationEdge, num? timeout, int? priority, num? scale, num? offset})
Returns a new AssetsMetricS7 instance.

Properties

accessLevel AccessLevel
getter/setter pairoverride-getter
activationEdge AssetsMetricS7ActivationEdgeEnum?
active edge for alarm, if category is alarm
getter/setter pair
bitOffset num?
Minimum value: 0
getter/setter pair
category List<MetricCategory>
getter/setter pairoverride-getter
dataBlockAddress num?
Minimum value: 0
getter/setter pair
dataType AssetsMetricS7DataTypeEnum
getter/setter pairoverride-getter
description String?
optional description for metric
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setteroverride
interval int
interval in ms
getter/setter pair
max num?
max value
getter/setter pairoverride-getter
memoryAddress num
Minimum value: 0
getter/setter pair
memoryArea AssetsMetricS7MemoryAreaEnum
getter/setter pair
min num?
min value
getter/setter pairoverride-getter
name String
metric name
getter/setter pairoverride-getter
offset num?
Optional offset
getter/setter pairoverride-getter
permissions MetricPermission
getter/setter pairoverride-getter
priority int?
Priority of the alarm: 0 = low, 1 = medium, 2 = high, 3 = critical
getter/setter pair
protocolType AssetsProtocolEnum
no setteroverride
retPolicy RetPolicy
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale num?
Optional scale - cannot be 0
getter/setter pairoverride-getter
stringLength num?
Minimum value: 0
getter/setter pair
tags Tags?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pairoverride-getter
timeout num?
alarm timeout in seconds
getter/setter pair
topic String?
topic to publish to
getter/setter pair
unit Unit?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AssetsMetricS7?
Returns a new AssetsMetricS7 instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) List<AssetsMetricS7>
mapFromJson(dynamic json) Map<String, AssetsMetricS7>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AssetsMetricS7>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.