AssetsMetricS7RequestBody class
Constructors
-
AssetsMetricS7RequestBody({AssetsMetricS7RequestBodyTypeEnum? type, List<
AssetsMetricS7> data = const []}) - Returns a new AssetsMetricS7RequestBody instance.
Properties
-
data
↔ List<
AssetsMetricS7> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ AssetsMetricS7RequestBodyTypeEnum?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AssetsMetricS7RequestBody? -
Returns a new AssetsMetricS7RequestBody instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AssetsMetricS7RequestBody> -
mapFromJson(
dynamic json) → Map< String, AssetsMetricS7RequestBody> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AssetsMetricS7RequestBody> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.