AssetsMetricS7Response class

Implemented types

Constructors

AssetsMetricS7Response({List<AssetsMetricS7> data = const []})
Returns a new AssetsMetricS7Response instance.

Properties

data List<AssetsMetricS7>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AssetsProtocolEnum
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AssetsMetricS7Response?
Returns a new AssetsMetricS7Response instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) List<AssetsMetricS7Response>
mapFromJson(dynamic json) Map<String, AssetsMetricS7Response>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AssetsMetricS7Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.