AssetsMetricS7TopicEnumTypeAssetsTransformer class

AssetsTransformation class that can encode an instance of AssetsMetricS7TopicEnum to String, and decode dynamic data back to AssetsMetricS7TopicEnum.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic data, {bool allowNull = true}) AssetsMetricS7TopicEnum?
Decodes a data to a AssetsMetricS7TopicEnum.
encode(AssetsMetricS7TopicEnum data) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited