AssetsParametersModbusRTUStopBitsEnum class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() double
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data, {bool allowNull = true}) AssetsParametersModbusRTUStopBitsEnum?
fromJson(dynamic value) AssetsParametersModbusRTUStopBitsEnum?

Constants

stopBits1 → const AssetsParametersModbusRTUStopBitsEnum
stopBits2 → const AssetsParametersModbusRTUStopBitsEnum
stopBits15 → const AssetsParametersModbusRTUStopBitsEnum
values → const List<AssetsParametersModbusRTUStopBitsEnum>
List of all possible values in this MetricModbusByteOrderEnum.