AssetsTransformsApi class

Constructors

AssetsTransformsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTransform(AssetsTransformsRequestBody AssetsTransformsRequestBody) Future<AssetsTransform?>
Create a new AssetsTransform
createTransformWithHttpInfo(AssetsTransformsRequestBody AssetsTransformsRequestBody) Future<Response>
Create a new AssetsTransform
deleteTransform(String id) Future<void>
Delete a AssetsTransform by ID
deleteTransformWithHttpInfo(String id) Future<Response>
Delete a AssetsTransform by ID
getTransform(String id, [List<PopulateTransformsQueryParameters>? populateQuery]) Future<AssetsTransform?>
Retrieve a specific AssetsTransform by ID
getTransforms([List<PopulateTransformsQueryParameters>? populateQuery]) Future<List<AssetsTransform>?>
Retrieve a list of AssetsTransforms
getTransformsWithHttpInfo([List<PopulateTransformsQueryParameters>? populateQuery]) Future<Response>
Retrieve a list of AssetsTransforms
getTransformWithHttpInfo(String id, [List<PopulateTransformsQueryParameters>? populateQuery]) Future<Response>
Retrieve a specific AssetsTransform by ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateTransform(String id, AssetsTransformsRequestBody AssetsTransformsRequestBody) Future<AssetsTransform?>
Update an existing AssetsTransform by ID
updateTransformWithHttpInfo(String id, AssetsTransformsRequestBody assetsTransformsRequestBody) Future<Response>
Update an existing AssetsTransform by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited