AssetsTransformsRequestBodyData class

Constructors

AssetsTransformsRequestBodyData({required String name, required String version, required AssetsTransformsRequestBodyDataKindEnum kind, required String value, String? description, String? type, GatewayModel? gatewayModel})
Returns a new AssetsTransformsRequestBodyData instance.

Properties

description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
gatewayModel GatewayModel?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
kind AssetsTransformsRequestBodyDataKindEnum
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
value String
getter/setter pair
version String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AssetsTransformsRequestBodyData?
Returns a new AssetsTransformsRequestBodyData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AssetsTransformsRequestBodyData>
mapFromJson(dynamic json) Map<String, AssetsTransformsRequestBodyData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AssetsTransformsRequestBodyData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.