DeviceModelIngestionConfig class
Constructors
-
DeviceModelIngestionConfig({List<
AssetsMetric> ? metrics}) - Returns a new DeviceModelIngestionConfig instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
metrics
↔ List<
AssetsMetric> ? -
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value, [AssetsProtocolEnum? protocol]) → DeviceModelIngestionConfig? -
Returns a new DeviceModelIngestionConfig instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< DeviceModelIngestionConfig> -
mapFromJson(
dynamic json) → Map< String, DeviceModelIngestionConfig> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< DeviceModelIngestionConfig> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.