DeviceModelMetricItemsApi class

Constructors

DeviceModelMetricItemsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

gaDeviceModelMetricItemsIdPost(String id, DeviceModelMetricItemRequest deviceModelMetricItemRequest) Future<DeviceModelMetricItemResponse?>
Create a new device model metric item
gaDeviceModelMetricItemsIdPostWithHttpInfo(String id, DeviceModelMetricItemRequest deviceModelMetricItemRequest) Future<Response>
Create a new device model metric item
gaDeviceModelMetricItemsIdPropIdDelete(String id, String propId) Future<void>
Delete a device model metric item by ID
gaDeviceModelMetricItemsIdPropIdDeleteWithHttpInfo(String id, String propId) Future<Response>
Delete a device model metric item by ID
gaDeviceModelMetricItemsReplaceAllMetricsIdPost(String xUserId, String xOrgId, String xAuthGid, String id, DeviceModelMetricItemRequest deviceModelMetricItemRequest) Future<DeviceModelMetricItemResponse?>
Create a new device model metric item
gaDeviceModelMetricItemsReplaceAllMetricsIdPostWithHttpInfo(String id, DeviceModelMetricItemRequest deviceModelMetricItemRequest) Future<Response>
Create a new device model metric item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited