DeviceModelsApi class

Constructors

DeviceModelsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDeviceModel(DeviceModelRequestBody DeviceModelRequestBody) Future<DeviceModel?>
Create a new device model
createDeviceModelWithHttpInfo(DeviceModelRequestBody DeviceModelRequestBody) Future<Response>
Create a new device model
deleteDeviceModel(String id) Future<void>
Delete a device model by ID
deleteDeviceModelWithHttpInfo(String id) Future<Response>
Delete a device model by ID
getDeviceModelById(String id, [PopulateFieldsQueryParameters? populateQuery]) Future<DeviceModel?>
Retrieve a specific device model by ID
getDeviceModelByIdWithHttpInfo(String id, [PopulateFieldsQueryParameters? populateQuery]) Future<Response>
Retrieve a specific device model by ID
getDeviceModels([PopulateFieldsQueryParameters? populateQuery]) Future<List<DeviceModel>?>
Retrieve a list of device models
getDeviceModelsWithHttpInfo([PopulateFieldsQueryParameters? populateQuery]) Future<Response>
Retrieve a list of device models
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateDeviceModel(String id, DeviceModelRequestBody DeviceModelRequestBody) Future<DeviceModel?>
Update an existing device model by ID
updateDeviceModelWithHttpInfo(String id, DeviceModelRequestBody DeviceModelRequestBody) Future<Response>
Update an existing device model by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited