DevicesApi class

Constructors

DevicesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDevice(DeviceRequestBody deviceRequestBody) Future<Device?>
Create a device
createDeviceWithHttpInfo(DeviceRequestBody deviceRequestBody) Future<Response>
Create a device
deleteDevice(String id) Future<void>
Delete device by ID
deleteDeviceWithHttpInfo(String id) Future<Response>
Delete device by ID
getDeviceById(String id, [List<PopulateDeviceQueryParameters>? populateQuery]) Future<Device?>
Get a single device
getDeviceByIdWithHttpInfo(String id, [List<PopulateDeviceQueryParameters>? populateQuery]) Future<Response>
Get a single device
getDevices([List<PopulateDeviceQueryParameters>? populateQuery]) Future<List<Device>?>
List all devices
getDevicesWithHttpInfo([List<PopulateDeviceQueryParameters>? populateQuery]) Future<Response>
List all devices
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateDevice(String id, DeviceRequestBody deviceRequestBody) Future<Device?>
Update device by ID
updateDeviceWithHttpInfo(String id, DeviceRequestBody deviceRequestBody) Future<Response>
Update device by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited