GatewayModel class

Constructors

GatewayModel({required num id, String? name, String? orderCode, String? deviceVersion, String? description, String? groupId, IngestionConfig? ingestionConfigData, Object? applications, Manufacturer? manufacturer, AssetsTransform? assetsTransform, SupportedGateway? supportedGateways, SpecialUuid? specialUuid, List<DeviceModel> deviceModels = const []})
Returns a new GatewayModel instance.

Properties

applications Object?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
assetsTransform AssetsTransform?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
deviceModels List<DeviceModel>
getter/setter pair
deviceVersion String?
getter/setter pair
groupId String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id num
getter/setter pair
ingestionConfigData IngestionConfig?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
manufacturer Manufacturer?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
name String?
getter/setter pair
orderCode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specialUuid SpecialUuid?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
supportedGateways SupportedGateway?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GatewayModel?
Returns a new GatewayModel instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GatewayModel>
mapFromJson(dynamic json) Map<String, GatewayModel>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GatewayModel>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.