GatewayModelsApi class

Constructors

GatewayModelsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createGatewayModel(GatewayModelsRequestBody GatewayModelsRequestBody) Future<GatewayModel?>
Create a new gateway model
createGatewayModelWithHttpInfo(GatewayModelsRequestBody GatewayModelsRequestBody) Future<Response>
Create a new gateway model
deleteGatewayModel(String id) Future<void>
Delete a gateway model by ID
deleteGatewayModelWithHttpInfo(String id) Future<Response>
Delete a gateway model by ID
getGatewayModelById(String id, [PopulateFieldsQueryParameters? populateQuery]) Future<GatewayModel?>
Retrieve a specific gateway model by ID
getGatewayModelByIdWithHttpInfo(String id, [PopulateFieldsQueryParameters? populateQuery]) Future<Response>
Retrieve a specific gateway model by ID
getGatewayModels([PopulateFieldsQueryParameters? populateQuery]) Future<List<GatewayModel>?>
Retrieve a list of gateway models
getGatewayModelsWithHttpInfo([PopulateFieldsQueryParameters? populateQuery]) Future<Response>
Retrieve a list of gateway models
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateGatewayModel(String id, GatewayModelsRequestBody GatewayModelsRequestBody) Future<GatewayModel?>
Update an existing gateway model by ID
updateGatewayModelWithHttpInfo(String id, GatewayModelsRequestBody GatewayModelsRequestBody) Future<Response>
Update an existing gateway model by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited