GatewayRequestBodyData class

Constructors

GatewayRequestBodyData({required String name, required String serialCode, required StatusEnum status, String? description, Object? operationalIngestionConfig, RequestConnectDisconnectBody? gatewayModel, RequestConnectDisconnectBody? plant})
Returns a new GatewayRequestBodyData instance.

Properties

description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
gatewayModel RequestConnectDisconnectBody?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
getter/setter pair
operationalIngestionConfig Object?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
plant RequestConnectDisconnectBody?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialCode String
getter/setter pair
status StatusEnum
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GatewayRequestBodyData?
Returns a new GatewayRequestBodyData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GatewayRequestBodyData>
mapFromJson(dynamic json) Map<String, GatewayRequestBodyData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GatewayRequestBodyData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.