GatewaysApi class

Constructors

GatewaysApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignLicense(String id, GatewayAssignLicenseRequestBody gatewayAssignLicenseRequestBody) Future<void>
Assign a license to a gateway
assignLicenseHttpInfo(String id, GatewayAssignLicenseRequestBody gatewayAssignLicenseRequestBody) Future<Response>
Assign a license to a gateway
createGateway(GatewayRequestBody GatewayRequestBody) Future<Gateway?>
Create a new gateway
createGatewayWithHttpInfo(GatewayRequestBody GatewayRequestBody) Future<Response>
Create a new gateway
deleteGateway(String id) Future<void>
Delete a gateway by ID
deleteGatewayWithHttpInfo(String id) Future<Response>
Delete a gateway by ID
disconnectLicense(String id, GatewayDisconnectLicenseRequestBody gatewayDisconnectLicenseRequestBody) Future<void>
Disconnect a license from a gateway
disconnectLicenseWithHttpInfo(String id, GatewayDisconnectLicenseRequestBody gatewayDisconnectLicenseRequestBody) Future<Response>
Disconnect a license from a gateway
getGatewayById(String id, [List<PopulateGatewayQueryParameters>? populateQuery]) Future<Gateway?>
Get a gateway by ID
getGatewayByIdWithHttpInfo(String id, List<PopulateGatewayQueryParameters>? populateQuery) Future<Response>
Get a gateway by ID
getGateways([List<PopulateGatewayQueryParameters>? populateQuery]) Future<List<Gateway>?>
Get all gateways
getGatewaysGetWithHttpInfo(List<PopulateGatewayQueryParameters>? populateQuery) Future<Response>
Get all gateways
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateGateway(String id, GatewayRequestBody GatewayRequestBody) Future<Gateway?>
Update a gateway by ID
updateGatewayWithHttpInfo(String id, GatewayRequestBody GatewayRequestBody) Future<Response>
Update a gateway by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited