LicensesApi class

Constructors

LicensesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLicense(String id, [List<PopulateLicenseQueryParameters>? populateQuery]) Future<License?>
Retrieve a specific license by ID
getLicenses([List<PopulateLicenseQueryParameters>? populateQuery]) Future<List<License>?>
Retrieve a list of licenses
getLicensesWithHttpInfo([List<PopulateLicenseQueryParameters>? populateQuery]) Future<Response>
Retrieve a list of licenses
getLicenseWithHttpInfo(String id, [List<PopulateLicenseQueryParameters>? populateQuery]) Future<Response>
Retrieve a specific license by ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerLicenseWithToken(LicenseRegisterWithTokenRequestBody LicenseRegisterWithTokenRequestBody) Future<License?>
Retrieve a license by token
registerLicenseWithTokenPostWithHttpInfo(LicenseRegisterWithTokenRequestBody LicenseRegisterWithTokenRequestBody) Future<Response>
Retrieve a license by token
resetLicense(String id) Future<void>
Reset a license
resetLicenseWithHttpInfo(String id) Future<Response>
Reset a license
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited