MetricPermission class

permissions: 0 = read, 1 = write, 2 = read+write

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() int
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) MetricPermission?
listFromJson(dynamic json, {bool growable = false}) List<MetricPermission>

Constants

number0 → const MetricPermission
number1 → const MetricPermission
number2 → const MetricPermission
values → const List<MetricPermission>
List of all possible values in this MetricPermission.