Plant class

Constructors

Plant({required num id, String? name, String? address, double? longitude, double? latitude, String? groupId, List<AssetsGroup>? group = const [], String? description, IngestionConfig? ingestionConfigData, DateTime? createdAt, DateTime? updatedAt, List<Gateway> gateways = const []})
Returns a new Plant instance.

Properties

address String?
getter/setter pair
createdAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
gateways List<Gateway>
getter/setter pair
group List<AssetsGroup>?
getter/setter pair
groupId String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id num
getter/setter pair
ingestionConfigData IngestionConfig?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
latitude double?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
longitude double?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Plant?
Returns a new Plant instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Plant>
mapFromJson(dynamic json) Map<String, Plant>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Plant>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.