PlantsApi class

Constructors

PlantsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPlant(PlantPostRequestBody plantPostRequestBody) Future<Plant?>
Create a plant
createPlantWithHttpInfo(PlantPostRequestBody plantPostRequestBody) Future<Response>
Create a plant
deletePlant(String id) Future<void>
Delete a plant
deletePlantWithHttpInfo(String id) Future<Response>
Delete a plant
getPlantById(String id, [List<PopulatePlantQueryParameters>? populateQuery]) Future<Plant?>
Get a specific plant by ID
getPlantByIdWithHttpInfo(String id, List<PopulatePlantQueryParameters>? populateQuery) Future<Response>
Get a specific plant by ID
getPlantGatewaysStatus(String id) Future<List<GatewayStatus>?>
Get all gateways
getPlantGatewaysStatusWithHttpInfo(String id) Future<Response>
Get all gateways status
getPlants([List<PopulatePlantQueryParameters>? populateQuery]) Future<List<Plant>?>
Get all plants
getPlantsWithHttpInfo(List<PopulatePlantQueryParameters>? populateQuery) Future<Response>
Get all plants
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updatePlant(String id, PlantPostRequestBody plantPostRequestBody) Future<Plant?>
Update a plant
updatePlantWithHttpInfo(String id, PlantPostRequestBody plantPostRequestBody) Future<Response>
Update a plant

Operators

operator ==(Object other) bool
The equality operator.
inherited