PopulateGroupQueryParameters class

retain policy tag

Implemented types

Properties

fields List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
key String
The underlying key of this enum member.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toQueryParam() Map<String, String>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited