RetPolicy class

retain policy tag

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) RetPolicy?
listFromJson(dynamic json, {bool growable = false}) List<RetPolicy>

Constants

agg10y → const RetPolicy
noagg3m → const RetPolicy
noagg6h → const RetPolicy
noagg6m → const RetPolicy
values → const List<RetPolicy>
List of all possible values in this RetPolicy.