StaticTag class

Constructors

StaticTag({required String key, required String value, bool active = false})
Returns a new StaticTag instance.

Properties

active bool
If true, this tag will be included in ingestion config
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
key String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StaticTag?
Returns a new StaticTag instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StaticTag>
mapFromJson(dynamic json) Map<String, StaticTag>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StaticTag>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.