SupportedGatewaysApi class

Constructors

SupportedGatewaysApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSupportedGateway(SupportedGatewayRequestBody supportedGatewayRequestBody) Future<SupportedGateway?>
Create a new supported gateway
createSupportedGatewayWithHttpInfo(SupportedGatewayRequestBody supportedGatewayRequestBody) Future<Response>
Create a new supported gateway
deleteSupportedGateway(String id) Future<void>
Delete a supported gateway by ID
deleteSupportedGatewayWithHttpInfo(String id) Future<Response>
Delete a supported gateway by ID
gaSupportedGatewaysGet() Future<List<SupportedGateway>?>
Retrieve a list of supported gateways
gaSupportedGatewaysGetWithHttpInfo() Future<Response>
Retrieve a list of supported gateways
getSupportedGateway(String id) Future<SupportedGateway?>
Retrieve a specific supported gateway by ID
getSupportedGatewayWithHttpInfo(String id) Future<Response>
Retrieve a specific supported gateway by ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateSupportedGateway(String id, SupportedGatewayRequestBody supportedGatewayRequestBody) Future<SupportedGateway?>
Update an existing supported gateway by ID
updateSupportedGatewayWithHttpInfo(String id, SupportedGatewayRequestBody supportedGatewayRequestBody) Future<Response>
Update an existing supported gateway by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited