Unit class

unit: from International System of Units (SI)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) Unit?
listFromJson(dynamic json, {bool growable = false}) List<Unit>

Constants

ampere → const Unit
angstrom → const Unit
astronomicalUnit → const Unit
atmosphere → const Unit
bar → const Unit
barn → const Unit
becquerel → const Unit
bit → const Unit
byte → const Unit
calorie → const Unit
candela → const Unit
coulomb → const Unit
cubicMeter → const Unit
cubicMeterPerSecond → const Unit
day → const Unit
decibel → const Unit
degreeCelsius → const Unit
degreeFahrenheit → const Unit
dyne → const Unit
electronvolt → const Unit
erg → const Unit
farad → const Unit
gallon → const Unit
gigabyte → const Unit
gray → const Unit
henry → const Unit
hertz → const Unit
hour → const Unit
inch → const Unit
joule → const Unit
joulePerKelvin → const Unit
kelvin → const Unit
kelvinPerWatt → const Unit
kilobyte → const Unit
kilogram → const Unit
kilogramPerCubicMeter → const Unit
kilogramPerSecond → const Unit
kilometer → const Unit
knots → const Unit
lightYear → const Unit
liter → const Unit
lumen → const Unit
lux → const Unit
mach → const Unit
megabyte → const Unit
meter → const Unit
meterPerSecond → const Unit
meterPerSecondSquared → const Unit
mile → const Unit
minute → const Unit
mole → const Unit
nauticalMile → const Unit
newton → const Unit
ohm → const Unit
ounce → const Unit
parsec → const Unit
pascal → const Unit
pint → const Unit
poise → const Unit
pound → const Unit
radian → const Unit
second → const Unit
siemens → const Unit
sievert → const Unit
squareMeter → const Unit
steradian → const Unit
stokes → const Unit
terabyte → const Unit
tesla → const Unit
ton → const Unit
tonne → const Unit
values → const List<Unit>
List of all possible values in this Unit.
volt → const Unit
watt → const Unit
weber → const Unit
yard → const Unit