AssetsConnectionOPCUA class
- Inheritance
-
- Object
- AssetsConnection
- AssetsConnectionOPCUA
Constructors
- AssetsConnectionOPCUA({required AssetsParametersOPCUA parameters})
- Returns a new AssetsConnectionOPCUA instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
getter/setter pairinherited
- parameters ↔ AssetsParametersOPCUA
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ AssetsProtocolEnum
-
finalgetter/setter pairinherited-setteroverride-getter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AssetsConnectionOPCUA? -
Returns a new AssetsConnectionOPCUA instance and imports its values from
valueif it's a Map, null otherwise.override -
listFromJson(
dynamic json, {bool growable = false}) → List< AssetsConnectionOPCUA> ? -
mapFromJson(
dynamic json) → Map< String, AssetsConnectionOPCUA> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AssetsConnectionOPCUA> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.