AssetsMetric class abstract
Constructors
Properties
- accessLevel → AccessLevel
-
no setter
-
category
→ List<
MetricCategory> -
no setter
- dataType → AssetsMetricsDataTypeEnum
-
no setter
- description → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → num?
-
no setter
- min → num?
-
no setter
- name → String
-
no setter
- offset → num?
-
no setter
- permissions → MetricPermission
-
no setter
- protocolType → AssetsProtocolEnum
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → num?
-
no setter
-
no setter
- unit → Unit?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → dynamic