LogbotAssets class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- AssetsTransforms ↔ AssetsTransformsApi
-
getter/setter pair
- deviceModelMetricItems ↔ DeviceModelMetricItemsApi
-
getter/setter pair
- deviceModels ↔ DeviceModelsApi
-
getter/setter pair
- devices ↔ DevicesApi
-
getter/setter pair
- gatewayModels ↔ GatewayModelsApi
-
getter/setter pair
- gateways ↔ GatewaysApi
-
getter/setter pair
- groups ↔ GroupsApi
-
getter/setter pair
- licenses ↔ LicensesApi
-
getter/setter pair
- manufacturers ↔ ManufacturersApi
-
getter/setter pair
- plants ↔ PlantsApi
-
getter/setter pair
- supportedGateways ↔ SupportedGatewaysApi
-
getter/setter pair